@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: PFDiskStore.pm 4759 2009-04-21 17:57:34Z sysjkf $
+#   $Id: PFDiskStore.pm 5098 2011-06-25 20:11:06Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ use MailScanner::Config;
 use vars qw($VERSION @DeletesPending);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 4759 $, 10;
+$VERSION = substr q$Revision: 5098 $, 10;
 
 # List of pending delete operations so we can clear up properly when killed
 @DeletesPending = ();
@@ -59,7 +59,7 @@ $VERSION = substr q$Revision: 4759 $, 10;
 #use vars qw($VERSION);
 #
 #### The package version, both in 1.23 style *and* usable by MakeMaker:
-#$VERSION = substr q$Revision: 4759 $, 10;
+#$VERSION = substr q$Revision: 5098 $, 10;
 
 # Attributes are
 #
@@ -170,7 +170,11 @@ sub DeleteUnlock {
   $deferpath =~ s/deferred/defer/gi;
   @DeletesPending = ($path, $deferpath);
 
-  unlink $path, $deferpath;
+  $path =~ /^(.*)$/;
+  $path = $1;
+  $deferpath =~ /^(.*)$/;
+  $deferpath = $1;
+  unlink $path, $deferpath; # TAINT
 
   MailScanner::Lock::unlockclose($this->{inhdhandle});
 
@@ -376,7 +380,9 @@ sub WriteHeader {
 
   my($hddirbase, $hddir1, $hddir2, $hdoutfile, $now);
   # Postfix wants the message file to have perms 0700 for some reason
-  chmod 0700, "$tfile";
+  $tfile =~ /^(.*)$/;
+  $tfile = $1;
+  chmod 0700, "$tfile"; # TAINT
   $now = time;
   if ($MailScanner::SMDiskStore::HashDirDepth == 2) {
     ($hddirbase, $hddir1, $hddir2, $hdoutfile) = 
@@ -409,8 +415,14 @@ sub WriteHeader {
       MailScanner::Sendmail::HDOutFileName($tfile);
     #print STDERR "tfile = $tfile and hdoutfile = $hdoutfile\n";
     # Update all the datestamps so that Postfix qmgr will see them
-    utime $now, $now, "$tfile";
-    rename "$tfile", "$hddirbase/$hdoutfile"
+    $tfile =~ /^(.*)$/;
+    $tfile = $1;
+    utime $now, $now, "$tfile"; # TAINT
+    $hddirbase =~ /^(.*)$/;
+    $hddirbase = $1;
+    $hdoutfile =~ /^(.*)$/;
+    $hdoutfile = $1;
+    rename "$tfile", "$hddirbase/$hdoutfile" # TAINT
       or MailScanner::Log::DieLog("Cannot rename clean %s to %s, %s",
                                   $tfile, $hdoutfile, $!);
     MailScanner::Log::InfoLog("Requeue: %s to %s", $message->{id},$hdoutfile);
@@ -472,7 +484,7 @@ sub ReadBody {
   return unless $b;
 
   # Restraint is disabled, do the whole message.
-  print "max message size is '$max'\n";
+  #print STDERR "max message size is '$max'\n";
   unless ($max) {
     while(defined($lastlineread = $b->Next())) {
       # End of line characters are already there, so don't add them
