@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Postfix.pm 5044 2010-07-31 16:58:58Z sysjkf $
+#   $Id: Postfix.pm 5098 2011-06-25 20:11:06Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ use Encode;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 5044 $, 10;
+$VERSION = substr q$Revision: 5098 $, 10;
 
 # Command-line options you need to give to sendmail to sensibly process a
 # message that is piped to it. Still need to add "-f" for specifying the
@@ -1748,6 +1748,7 @@ sub FindHashDirDepth {
         # same expression as $file [mumble mumble grrr mumble mumble]
         #print STDERR "Reading file $file from list\n";
         # Split pathname into dir and file again
+        my $fullpath = $file;
         ($queuedirname, $h1, $h2, $file) = ($1,$2,$3,$4)
           if $MailScanner::SMDiskStore::HashDirDepth == 2 &&
              $file =~ /^(.*)\/(.)\/(.)\/([^\/]+)$/;
@@ -1769,7 +1770,7 @@ sub FindHashDirDepth {
         # Don't put a random number on the end, put a reasonable hash of
         # the file on the end.
         # JKF 20090423 Add a "P" in the middle of so it cannot be a number.
-        my $id = $idtemp . '.' . PostfixKey($file);
+        my $id = $idtemp . '.' . PostfixKey($fullpath);
         #print STDERR "ID = $id\n";
         my $idorig = $idtemp;
 
@@ -1786,6 +1787,7 @@ sub FindHashDirDepth {
         }
         next unless $newmessage;
         next if $newmessage->{INVALID};
+        $newmessage->WriteHeaderFile(); # Write the file of headers
 
         # JKF 20090301 Skip this message if $id has been scanned
         # too many times.
@@ -1799,7 +1801,7 @@ sub FindHashDirDepth {
           my $nexttime = time + 120 + int(rand(240)); # 4 +- 2 minutes
           #my $nexttime = time + 10 + int(rand(20)); # 4 +- 2 minutes
           my @attempts = $MailScanner::ProcDBH->selectrow_array(
-                           $MailScanner::SthSelectRows, undef, $id);
+                         $MailScanner::SthSelectRows, undef, $id);
           #my @attempts = $MailScanner::ProcDBH->selectrow_array(
           #"SELECT id,count,nexttime FROM processing WHERE (id='" . $id . "')");
           #print STDERR "id       = \"$attempts[0]\"\n";
@@ -1862,7 +1864,8 @@ sub FindHashDirDepth {
             if $DirtyMsgs>=$MaxDirtyM;
           $HitLimit4 = 1
             if $DirtyBytes>=$MaxDirtyB;
-          $newmessage->WriteHeaderFile(); # Write the file of headers
+          # Moved this further up
+          #$newmessage->WriteHeaderFile(); # Write the file of headers
         } else {
           $newmessage->NeedsScanning(0);
           $CleanMsgs++;
@@ -1873,7 +1876,8 @@ sub FindHashDirDepth {
             if $CleanBytes>=$MaxCleanB;
           # Will have to add a WriteHeaderFile() here to implement
           # single-file archiving of messages.
-          $newmessage->WriteHeaderFile(); # Write the file of headers
+          # Moved this further up
+          #$newmessage->WriteHeaderFile(); # Write the file of headers
         }
       }
       umask 0077; # Safety net as stopped creating files
