@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: SA.pm 5018 2010-05-26 16:13:59Z sysjkf $
+#   $Id: SA.pm 5090 2011-03-23 17:50:47Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ use Compress::Zlib;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 5018 $, 10;
+$VERSION = substr q$Revision: 5090 $, 10;
 
 # Attributes are
 #
@@ -564,7 +564,9 @@ sub Checks {
   @SAheaders = grep !/^$fromheader\:/i, @SAheaders;
   @SAheaders = grep !/^\s*$/, @SAheaders; # ditch blank lines
 
-  push(@WholeMessage, $fromheader . ': ' . $message->{from} . "\n")
+  # Fix for RP_8BIT rule issue by Steve Freegard
+  #push(@WholeMessage, $fromheader . ': ' . $message->{from} . "\n")
+  unshift(@SAheaders, $fromheader . ': ' . $message->{from} . "\n")
     if $fromheader;
 
   # Add the spamvirusreport to the input to SA.
@@ -572,10 +574,19 @@ sub Checks {
   my $svheader = MailScanner::Config::Value('spamvirusheader', $message);
   if ($svheader && $message->{spamvirusreport}) {
     $svheader =~ s/:$//;
-    push(@WholeMessage, $svheader . ': ' . $message->{spamvirusreport} . "\n");
+    #push(@WholeMessage, $svheader . ': ' . $message->{spamvirusreport} . "\n");
+    unshift(@SAheaders, $svheader . ': ' . $message->{spamvirusreport} . "\n");
     #print STDERR "Added $svheader: " . $message->{spamvirusreport} . "\n";
   }
 
+  # Return-Path header should only be present on final delivery.
+  # See RFC5321 Section 4.4.
+  # Sendmail appears to add a placeholder Return-Path header which it uses
+  # for expansion later, unfortunately this placeholder uses high-bit chars.
+  # So we remove the header and create one from the envelope for SA.
+  @SAheaders = grep !/^Return-Path\:/i, @SAheaders;
+  unshift(@SAheaders, 'Return-Path: <' . $message->{from} . ">\n");
+
   #push(@WholeMessage, $global::MS->{mta}->OriginalMsgHeaders($message, "\n"));
   push(@WholeMessage, @SAheaders);
   #print STDERR "Headers are : " . join(', ', @WholeMessage) . "\n";
